package com.zx.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;

import com.zx.domain.req.JdbcClass;
import com.zx.service.Impl.KvtService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import java.util.List;

/** 控制层
 * @ClassDescription:
 * @JdkVersion: 17
 * @Author: zhangxu
 * @Created: 2024/4/20 11:21
 */
@RestController
@RequestMapping("/jdbc")
public class KvtController extends BaseController {


    @Autowired
    private KvtService kvtService;

    /**
     * 查询【请填写功能名称】列表
     */
    @RequiresPermissions("system:source:list")
    @GetMapping("/list")
    public Result<TableDataInfo<JdbcClass>> list(JdbcClass jdbcClass)
    {
        startPage();
        List<JdbcClass> list = kvtService.selectList(jdbcClass);
        return getDataTable(list);
    }

    @PostMapping("/AssetsList")
    public Result assetsList(@RequestBody JdbcClass jdbcClass)
    {
        return kvtService.assesList(jdbcClass);
    }

    @PostMapping("/SynchronousData")
    public Result synchronousData(@RequestBody JdbcClass jdbcClass)
    {
        return kvtService.synchronousData(jdbcClass);
    }
   /**
    * 数据结构
    * */
    @PostMapping("/DataAssetList")
    public Result dataAssetList(@RequestBody JdbcClass jdbcClass)
    {
        return kvtService.dattaList(jdbcClass);
    }

    @PostMapping("/AssetModelList")
    public Result assetModelList(@RequestBody JdbcClass jdbcClass)
    {
        return kvtService.assrtModelList(jdbcClass);
    }

    @PostMapping("/StructureList")
    public Result structureList(@RequestBody JdbcClass jdbcClass)
    {
        return kvtService.getTableList(jdbcClass);
    }



    /**
     * 获取【请填写功能名称】详细信息
     */
    @RequiresPermissions("system:source:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(kvtService.selectJdbcById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @RequiresPermissions("system:source:add")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody JdbcClass jdbcClass)
    {
        return toAjax(kvtService.insertJdbc(jdbcClass));
    }

    /**
     * 测试连接
     */
    @Log(title = "测试连接", businessType = BusinessType.INSERT)
    @PostMapping("/TestConnection")
    public Result testConnection(@RequestBody JdbcClass jdbcClass) throws ClassNotFoundException {
        return kvtService.testConn(jdbcClass);
    }

    /**
     * 修改【请填写功能名称】
     */
    @RequiresPermissions("system:source:edit")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody JdbcClass jdbcClass)
    {
        return toAjax(kvtService.updateJdbc(jdbcClass));
    }

    /**
     * 删除【请填写功能名称】
     */
    @RequiresPermissions("system:source:remove")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(kvtService.deleteAllJdbc(ids));
    }


    @GetMapping("/Statistics")
    public Result statistics(){
        return kvtService.statistics();
    }








}
