package com.zx.service.Impl;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.zx.domain.AssetsData;
import com.zx.domain.DataKvt;
import com.zx.domain.req.*;

import com.zx.mapper.AssetModelMapper;
import com.zx.mapper.DataAssetMapper;
import com.zx.mapper.KvtMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.*;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/** 实现层
 * @ClassDescription:
 * @JdkVersion: 17
 * @Author: zhangxu
 * @Created: 2024/4/20 11:21
 */
@Service
public class KvtServiceImpl implements KvtService{

    @Autowired
    private KvtMapper kvtMapper;

    @Autowired
    private DataAssetMapper dataAssetMapper;

    @Autowired
    private AssetModelMapper assetModelMapper;



    @Autowired
    private DictionaryServiceImpl dictionaryService;


    @Override
    public JdbcClass selectJdbcById(Long id) {

        return kvtMapper.selectJdbcById(id);
    }

    @Override
    public List<JdbcClass> selectList(JdbcClass jdbcClass) {
        List<JdbcClass> jdbcClasses = kvtMapper.selectList(jdbcClass);
        return jdbcClasses;
    }

    @Override
    public int insertJdbc(JdbcClass jdbcClass) {
        jdbcClass.setCreateTime(DateUtils.getNowDate());
        jdbcClass.setCreateBy(SecurityUtils.getUsername());
        int i = kvtMapper.insertJdbc(jdbcClass);
        return i;
    }


    @Override
    public int updateJdbc(JdbcClass jdbcClass) {
        jdbcClass.setCreateTime(DateUtils.getNowDate());
        jdbcClass.setCreateBy(SecurityUtils.getUsername());
        int i = kvtMapper.updateJdbc(jdbcClass);
        return i;
    }

    @Override
    public int deleteJdbc(Long id) {
        return 0;
    }

    @Override
    public int deleteJdbc(Long[] id) {
        deleteChildren(id);
        return  kvtMapper.deleteJdbc(id);
    }


    public void deleteChildren(Long[] id) {
        List<DataAsset> dataAssetList = dataAssetMapper.getDataAssetList(id);
        if (!dataAssetList.isEmpty()){
            List<Long> list = dataAssetList.stream().map(DataAsset::getId).toList();
            List<AssetModel> assetModelList = assetModelMapper.getAssetModelList(list);
            dataAssetMapper.deleteDataAssetByIds(list.toArray(Long[]::new));
         if (!assetModelList.isEmpty()){
             List<Long> list1 = assetModelList.stream().map(AssetModel::getId).toList();
             assetModelMapper.deleteAssetModelByIds(list1.toArray(Long[]::new));
         }

        }

    }

    @Override
    public int deleteAllJdbc(Long[] ids) {
        return kvtMapper.deleteAllJdbc(ids);
    }

    @Override
    public Result testConn(JdbcClass jdbcClass) throws ClassNotFoundException {
//        // 获取JdbcClass对象中的数据库连接信息
//        String user= jdbcClass.getUsername();
//        String pwd= jdbcClass.getPassword();
//        String driver="com.mysql.cj.jdbc.Driver";
//        // 构造数据库连接URL
//        String url="jdbc:mysql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
//        // 如果有额外的连接参数，则附加到URL后
//        if (jdbcClass.getConnectionParam()!=null && jdbcClass.getConnectionParam()!=""){
//            url=url+"?"+jdbcClass.getConnectionParam();
//        }
//        Connection connection=null;
//        try {
//            // 加载数据库驱动
//            Class.forName(driver);
//        } catch (ClassNotFoundException e) {
//            // 如果驱动类未找到，返回连接失败信息
//            return Result.error("连接失败,请检查");
//        }
//        try {
//            // 尝试获取数据库连接并关闭
//            connection= DriverManager.getConnection(url,user,pwd);
//            connection.close();
//        } catch (Exception e) {
//            // 如果连接过程中出现异常，返回连接失败信息
//            return Result.error("连接失败");
//        }
//        // 连接成功，返回成功信息
//        return Result.success("连接成功");

//        if (jdbcClass.getType().equals("MySql")){
//        String type = jdbcClass.getType();
//        type="mysql";
        String user= jdbcClass.getUsername();
        String pwd= jdbcClass.getPassword();
        String driver="com.mysql.cj.jdbc.Driver";
        // 构造数据库连接URL
        String url="jdbc:mysql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
        // 如果有额外的连接参数，则附加到URL后
        if (jdbcClass.getConnectionParam()!=null && jdbcClass.getConnectionParam()!=""){
            url=url+"?"+jdbcClass.getConnectionParam();
        }
        Connection connection=null;
            try {
                Class.forName(driver);
            } catch (ClassNotFoundException e) {
                 return Result.error("连接失败");
            }
            try {
                connection=DriverManager.getConnection(url,user,pwd);
                connection.close();
            } catch (Exception e) {
                return Result.success("连接成功");
            }
//        }else {
//            String user= jdbcClass.getUsername();
//            String pwd= jdbcClass.getPassword();
//            String driver="org.postgresql.Driver";
//            String uel="jdbc:postgresql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
//            if (jdbcClass.getConnectionParam()!=null&&jdbcClass.getConnectionParam()!=""){
//                uel=uel+"?"+jdbcClass.getConnectionParam();
//            }
//            Connection connection=null;
//            try {
//                Class.forName(driver);
//            } catch (ClassNotFoundException e) {
//                return Result.error("连接失败");
//            }
//            try {
//                connection=DriverManager.getConnection(uel,pwd,user);
//                connection.close();
//            } catch (SQLException e) {
//                return Result.error("链接失败");
//            }


        return Result.success("连接成功");

    }

    @Override
    public Result assesList(JdbcClass jdbcClass) {
        AssetsData assets = getAssets(jdbcClass);
        return Result.success(assets);
    }

    @Override
    public Result getTableList(JdbcClass jdbcClass) {
        AssetsData data = getData(jdbcClass);
        return Result.success(data);
    }
    /**
     *查询一共多少条数据
     *
     * */
    @Override
    public Result getCount(JdbcClass jdbcClass) {
        String user =jdbcClass.getUsername();
        String pwd=jdbcClass.getPassword();
        String driver="com.mysql.cj.jdbc.Driver";
        String jdbcUrl="jdbc:mysql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
        Connection connection=null;

        try {
            Class.forName(driver);
            connection=DriverManager.getConnection(jdbcUrl,user,pwd);
        } catch (ClassNotFoundException | SQLException e) {
            throw new RuntimeException(e);
        }
        try {
            String sql="SELECT COUNT(*)FROM information_schema.tables WHERE table_schema =?";
            PreparedStatement preparedStatement = connection.prepareStatement(sql);
            preparedStatement.setString(1,jdbcClass.getDatabaseName());
            ResultSet resultSet = preparedStatement.executeQuery();
            int anInt = resultSet.getInt(1);
            return Result.success(anInt);
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }finally {
            try {
                connection.close();

            } catch (SQLException e) {
                throw new RuntimeException(e);
            }
        }

    }




    public AssetsData getData(JdbcClass jdbcClass){
        String user=jdbcClass.getUsername();
        String pwd=jdbcClass.getPassword();
        String driver="com.mysql.cj.jdbc.Driver";
        String jdbcUrl="jdbc:mysql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
        Connection connection=null;
        List<Map<String,DataKvt>> list = new ArrayList<>();
        HashMap<String, String> hashMap = new HashMap<>();
        try {
            Class.forName(driver);
            connection=DriverManager.getConnection(jdbcUrl,pwd,user);
        } catch (ClassNotFoundException | SQLException e) {
            throw new RuntimeException(e);
        }
        try {
            PreparedStatement preparedStatement = connection.prepareStatement(jdbcClass.getSql());
            ResultSet resultSet = preparedStatement.executeQuery();
            ResultSetMetaData metaData = resultSet.getMetaData();
            for (int i = 0; i < metaData.getColumnCount(); i++) {
                String substring = metaData.getColumnClassName(i).substring(metaData.getColumnClassName(i).indexOf("java.lang") + 10);
                hashMap.put(metaData.getColumnName(i),substring);
            }
            int columnCount = metaData.getColumnCount();
            while (resultSet.next()){
                Map<String,DataKvt> map = new HashMap<>();
                for (int i = 0; i < columnCount; i++) {
                     //根据列索引或列名获取数据
                    String columnName = metaData.getColumnName(i);
                    String type = hashMap.get(columnName);
                    Object value = resultSet.getObject(i);
                    if (value==null){
                        map.put(columnName,new DataKvt("",type));
                    }else {
                        map.put(columnName,new DataKvt(value.toString(),""));
                    }
                }
                list.add(map);
            }
            preparedStatement.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }
        AssetsData assetsData = new AssetsData();
        assetsData.setKvtList(list);
        assetsData.setTableAssets(hashMap);
        return assetsData;
    }

    public Map<String,String> getTypeMap(JdbcClass dataSource, String tableName){
        String jdbcUrl="";
        String sql="select * from "+tableName;
        String driver="com.mysql.cj.jdbc.Driver";
        jdbcUrl = "jdbc:mysql://"+dataSource.getLinkAddress()+":"+dataSource.getPort()+"/"+dataSource.getDatabaseName();
//        if (dataSource.getType().equals("MySql")){
//            sql = "select * from "+tableName;
//        }else{
//            sql = "select * from "+dataSource.getModeName()+"."+tableName;
//        }
        Connection conn = null;
        Map<String, String> map = new HashMap<>();
        try {
            Class.forName(driver);
            conn = DriverManager.getConnection(jdbcUrl, dataSource.getUsername(), dataSource.getPassword());
        } catch (SQLException | ClassNotFoundException e) {
            throw new RuntimeException(e);
        }
        try {
            PreparedStatement pst = null;
            pst = conn.prepareStatement(sql);
            ResultSet resultSet = pst.executeQuery();
            ResultSetMetaData rsd = resultSet.getMetaData();
            for(int i = 1; i <= rsd.getColumnCount(); i++) {
                String substring="";
                if (rsd.getColumnClassName(i).contains(".")){
                    String[] split = rsd.getColumnClassName(i).split("\\.");
                    substring = split[split.length-1];
                }else{
                    substring = rsd.getColumnClassName(i);
                }

                map.put(rsd.getColumnName(i),substring);
            }
            pst.close();
            pst=null;
        } catch (SQLException e) {
            throw new RuntimeException(e);
        }
        return map;
    }

    public List<AssetModel> getTableAssets(JdbcClass jdbcClass,String tableName){
        // 初始化数据库连接信息
        String user= jdbcClass.getUsername(); // 获取用户名
        String pwd= jdbcClass.getPassword(); // 获取密码
        String driver="com.mysql.cj.jdbc.Driver"; // 初始化驱动字符串
        String jdbcUrl= "jdbc:mysql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
        // 初始化数据库连接URL
        // 根据数据库类型构造相应的URL
//        url="jdbc:"+jdbcClass.getType().toLowerCase()+"://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
//        // 如果是Oracle数据库，则使用特定的URL格式
//        if (jdbcClass.getType().equals("oracle")){
//            url="jdbc:oracle:thin:@"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+":"+jdbcClass.getDatabaseName();
//        }
//        // 如果是PostgreSQL数据库
//        if (jdbcClass.getType().equals("postgresql")){
//            url="jdbc:postgresql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
//        }
//        // 如果是SQL Server数据库
//        if (jdbcClass.getType().equals("sqlserver")){
//            url="jdbc:sqlserver://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+";DatabaseName="+jdbcClass.getDatabaseName();
//        }
//        // 如果是MySQL数据库
//        if (jdbcClass.getType().equals("mysql")){
//            url="jdbc:mysql://"+jdbcClass.getLinkAddress()+":"+jdbcClass.getPort()+"/"+jdbcClass.getDatabaseName();
//        }
        // 定义空的connection
        Connection connection=null;
        List<AssetModel> assetsData = new ArrayList<>(); // 用于存储表结构信息的列表
        Map<String, String>  hashMap = getTypeMap(jdbcClass,tableName); //临时使用的HashMap

        // 尝试加载驱动并建立数据库连接
        try {
            //jdbcClass.getJdbcDriver()
            Class.forName(driver); // 加载驱动
            connection=DriverManager.getConnection(jdbcUrl,user,pwd); // 建立连接
        } catch (SQLException|ClassNotFoundException e) {
            throw new RuntimeException(e); // 处理异常
        }
        DatabaseMetaData metaData = null;
        try {
            metaData = connection.getMetaData(); // 获取元数据
            // 查询列信息
            ResultSet columns = metaData.getColumns(jdbcClass.getDatabaseName(), jdbcClass.getModeName(), tableName,"%");
            // 查询主键信息
            ResultSet primaryKeys = metaData.getPrimaryKeys(jdbcClass.getDatabaseName(), jdbcClass.getModeName(), tableName);
            String primaryKeyColumnName=""; // 用于存储主键列名
            // 处理主键列信息
            while (primaryKeys.next()){
                primaryKeyColumnName=primaryKeys.getString("COLUMN_NAME");
            }
            // 处理所有列的信息
            while (columns.next()){
                AssetModel assetModel = new AssetModel(); // 创建新的AssetModel实例
                // 提取并设置列信息到AssetModel
                String columnName = columns.getString("COLUMN_NAME");

                String typeName = columns.getString("TYPE_NAME");
                int columnSize = columns.getInt("COLUMN_SIZE");
                int decimalDigits = columns.getInt("DECIMAL_DIGITS");
                String isNullable = columns.getString("IS_NULLABLE");
                String columnDef = columns.getString("COLUMN_DEF");
                String remarks = columns.getString("REMARKS");
                assetModel.setCreateTime(new Date());
                assetModel.setCreateBy(SecurityUtils.getUsername());

                assetModel.setLength(String.valueOf(columnSize));
                assetModel.setDecimalPlaces(String.valueOf(decimalDigits));
                assetModel.setName(columnName);

                assetModel.setType(typeName);
                assetModel.setMappingType(hashMap.get(columnName));

                assetModel.setDictKey("");
                assetModel.setIsDict("");

                assetModel.setIsNull(isNullable.substring(0,1));
                assetModel.setDefaultValue(columnDef);


                // 标记是否为主键
                if (columnName.equals(primaryKeyColumnName)){
                    assetModel.setIsPrimaryKey("Y");
                } else {
                    assetModel.setIsPrimaryKey("N");
                }
                // 设置列注释
                if (remarks==null||remarks==""){
                    assetModel.setComment("-");
                }else {
                    assetModel.setComment(remarks);
                }
                // 设置默认值
                if (columnDef==null||columnDef==""){
                    assetModel.setDefaultValue("-");
                }else {
                    assetModel.setDefaultValue(columnDef);
                }
                assetsData.add(assetModel); // 将处理好的信息添加到列表中
            }
            // 关闭资源
            primaryKeys.close();
            connection.close();
            columns.close();
        } catch (SQLException ex) {
            ex.printStackTrace(); // 处理异常
        }


//        // 遍历查询结果，填充TableAssets对象列表
//            while (resultSet.next()){
//                AssetModel assetModel = new AssetModel();
//                assetModel.setComment(resultSet.getString("COLUMN_COMMENT"));
//                assetModel.setName(resultSet.getString("COLUMN_NAME"));
//                if (resultSet.getString("CHARACTER_MAXIMUM_LENGTH")!=null){
//                    assetModel.setLength(resultSet.getString("CHARACTER_MAXIMUM_LENGTH"));
//                }else if (resultSet.getString("NUMERIC_PRECISION")!=null){
//                    assetModel.setLength(resultSet.getString("NUMERIC_PRECISION"));
//                }else{
//                    assetModel.setLength("-");
//                }
//                if (resultSet.getString("NUMERIC_SCALE")!=null){
//                    assetModel.setDecimalPlaces(resultSet.getString("NUMERIC_SCALE"));
//                }else{
//                    assetModel.setDecimalPlaces("-");
//                }
//
//                //是否不可为空
//                if (resultSet.getString("IS_NULLABLE").equals("NO")){
//                    assetModel.setIsNull("N");
//                }else{
//                    assetModel.setIsNull("Y");
//                }
//                //是否有默认值
//                if (resultSet.getString("COLUMN_DEFAULT")!=null){
//                    assetModel.setDefaultValue(resultSet.getString("COLUMN_DEFAULT"));
//                }else{
//                    assetModel.setDefaultValue("-");
//                }
//                assetModel.setIsDict("");
//                assetModel.setDictKey("");
//                assetModel.setType(resultSet.getString("DATA_TYPE"));
//                //是否主键
//                if ("PRI".equals(resultSet.getString("COLUMN_KEY"))){
//                    assetModel.setIsPrimaryKey("Y");
//                }else{
//                    assetModel.setIsPrimaryKey("N");
//                }
//                assetModel.setCreateBy(SecurityUtils.getUsername());
//                assetModel.setCreateTime(new Date());
//                assetModel.setMappingType("String");
//                assetsData.add(assetModel);
//            }
//            preparedStatement.close();
//        } catch (SQLException e) {
//            e.printStackTrace();
//        }
        return assetsData;
    }


    public AssetsData getAssets(JdbcClass jdbcClass){
       String jdbcUrl="";
       String user="";
       String password="";
        List<Map<String, DataKvt>> kvtList = new ArrayList<>();
        Connection conn=null;
        HashMap<String, String> map = new HashMap<>();
        List<AssetModel> tableAssets = getTableAssets(jdbcClass,jdbcClass.getTableName());
        try {
            Class.forName(jdbcClass.getJdbcDriver());
            conn = DriverManager.getConnection(jdbcUrl, user, password);
            PreparedStatement preparedStatement = conn.prepareStatement("select * from "+ jdbcClass.getTableName()+"+where 1=1");
            ResultSet resultSet = preparedStatement.executeQuery();
            ResultSetMetaData rsd = resultSet.getMetaData();
            for(int i = 1; i <= rsd.getColumnCount(); i++) {
                String substring = rsd.getColumnClassName(i).substring(rsd.getColumnClassName(i).indexOf("java.lang.") + 10);
                System.out.print("java类型："+substring);
                System.out.print("  数据库类型:"+rsd.getColumnTypeName(i));
                System.out.print("  字段名称:"+rsd.getColumnName(i));
                System.out.println();
                map.put(rsd.getColumnName(i),substring);
            }
            for (AssetModel tableAsset : tableAssets) {
                tableAsset.setMappingType(map.get(tableAsset.getType()));
            }
            preparedStatement.close();

        } catch (SQLException e) {
            throw new RuntimeException(e);
        } catch (ClassNotFoundException e) {
            throw new RuntimeException(e);
        }
        AssetsData assetsModule = new AssetsData();
        assetsModule.setKvtList(kvtList);
        assetsModule.setTableAssets(map);
        return assetsModule;
    }

    /**
     * 公共用户名
     * 密码  无用
     * 地址
     * */
//    public void method(JdbcClass jdbcClass){
//        String user=jdbcClass.getUsername();
//        String pwd=jdbcClass.getPassword();
//        String jdbc = "com.mysql.cj.jdbc.Driver";
//        String jdbcUrl = "jdbc:mysql://" + jdbcClass.getLinkAddress() + ":" + jdbcClass.getPort() + "/" + jdbcClass.getDatabaseName();
//    }

    /**
     *
     * 数据的同步
     * */

    @Override
    public Result synchronousData(JdbcClass jdbcClass) {
        deleteChildren(new Long[]{jdbcClass.getId()});
        // 构造查询MySQL数据库中表信息的SQL语句
        String mysql = "SELECT TABLE_NAME t_name,TABLE_COMMENT table_comment,TABLE_ROWS table_rows,(SELECT count(*) FROM INFORMATION_SCHEMA.columns WHERE TABLE_SCHEMA = '"+jdbcClass.getDatabaseName()+"' and TABLE_NAME=t_name) fields FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA='"+jdbcClass.getDatabaseName()+"'";

        // 从JdbcClass实例获取数据库连接所需的用户、密码和驱动信息
        String user = jdbcClass.getUsername();
        String pwd = jdbcClass.getPassword();
        String jdbc = "com.mysql.cj.jdbc.Driver";
        // 构造数据库连接的URL
        String jdbcUrl = "jdbc:mysql://" + jdbcClass.getLinkAddress() + ":" + jdbcClass.getPort() + "/" + jdbcClass.getDatabaseName();
        // 声明数据库连接变量
        Connection connection = null;
        // 初始化数据资产列表
        ArrayList<DataAsset> dataAssets = new ArrayList<>();
        try {
            // 加载数据库驱动
            Class.forName(jdbc);

            // 获取数据库连接
            connection = DriverManager.getConnection(jdbcUrl, user, pwd);

            // 准备SQL语句并执行查询
            PreparedStatement preparedStatement = connection.prepareStatement(mysql);
            //在Java的数据库编程中,PreparedStatement是一种高效的执行SQL语句的方式。
            // 其中,executeQuery()是PreparedStatement类中的一个方法,用于执行SELECT语句并返回查询结果。
            ResultSet resultSet = preparedStatement.executeQuery();
            // 遍历查询结果，构造数据资产对象并填充信息
            while (resultSet.next()) {
                DataAsset dataAsset = new DataAsset();
                dataAsset.setTableName(resultSet.getString("t_name"));
                dataAsset.setTableComment(resultSet.getString("table_comment"));
                dataAsset.setTableCount(Long.valueOf(resultSet.getString("table_rows")));
                dataAsset.setFields(Long.valueOf(resultSet.getString("fields")));
                dataAsset.setDataSourceId(jdbcClass.getId());
                dataAsset.setCreateBy(SecurityUtils.getUsername());
                dataAsset.setCreateTime(new java.util.Date());
                dataAssets.add(dataAsset);
            }
            // 批量插入数据资产信息
            dataAssetMapper.batchInsert(dataAssets);
            // 遍历数据资产列表，为每个表获取详细的资产信息，并批量插入
            for (DataAsset dataAsset : dataAssets) {
                List<AssetModel> tableAssets = getTableAssets(jdbcClass, dataAsset.getTableName());
                if (!tableAssets.isEmpty()){
                    tableAssets.stream().forEach(assetModel -> assetModel.setDataAssetId(dataAsset.getId()));
                }else {
                    System.out.println("不能为空");
                }

                assetModelMapper.batchInsert(tableAssets);
            }
        } catch ( SQLException | ClassNotFoundException  e) {
            // 抛出运行时异常，封装SQLException和ClassNotFoundException
            throw new RuntimeException(e);
        }

        // 返回操作成功的结果
        return Result.success();
    }


//    @Override
//    public Result dataAssetList(DataSource dataSource) {
//        DataAsset dataAsset = new DataAsset();
//        dataAsset.setDataSourceId(dataSource.getId());
//        List<DataAsset> dataAssets = dataAssetMapper.selectDataAssetList(dataAsset);
//        return Result.success(dataAssets);
//    }

    @Override
        public Result dattaList (JdbcClass jdbcClass){
        DataAsset dataAsset = new DataAsset();
        dataAsset.setDataSourceId(jdbcClass.getId());
        List<DataAsset> dataAssets = dataAssetMapper.selectDataAssetList(dataAsset);
        return Result.success(dataAssets);
        }


    /**
     * 统计数据资产的相关信息。
     * 该方法不接受任何参数，返回数据资产的统计结果，包括数据资产的数量、数据模型总数和数据表总数。
     *
     * @return Result<Statistics> 包含统计数据的Result对象，其中Statistics包含数据资产数量、数据模型总数和数据表总数。
     */

    @Override
    public Result statistics() {
        // 从kvtMapper中查询所有数据资产，并将其ID提取为列表
        List<JdbcClass> dataAssets = kvtMapper.selectList(new JdbcClass());
        List<Long> list = dataAssets.stream().map(JdbcClass::getId).toList();

        // 根据数据资产的ID列表，查询每个数据资产的数据模型和数据表数量
        List<DataAsset> dataAssets1 = dataAssetMapper.selectDataAssetBatchId(list);

        // 初始化统计信息
        Statistics statistics = new Statistics();
        // 设置数据资产的数量
        statistics.setDataAsset(Long.valueOf(dataAssets.size()));

        // 计算所有数据资产的数据模型总数和数据表总数
        long sum1;
        long sum2=0;
        sum1=dataAssets1.stream().mapToLong(value -> Long.valueOf(value.getFields())).sum();
        sum2=dataAssets1.stream().mapToLong(value -> Long.valueOf(value.getTableCount())).sum();

        // 设置数据模型总数和数据表总数
        statistics.setAssetModel(sum1);
        statistics.setDataModel(sum2);

        // 返回统计结果
        return Result.success(statistics);
    }

        @Override
        public Result assrtModelList(JdbcClass jdbcClass){
            AssetModel assetModel = new AssetModel();
            assetModel.setDataAssetId(jdbcClass.getId());
            List<AssetModel> assetModels = assetModelMapper.selectAssetModelList(assetModel);
            List<String> list = assetModels.stream().map(AssetModel::getDictKey).toList();
            if (!list.isEmpty()){
                Result<List<Dictionary>> dictionaryDataList = dictionaryService.getDictionaryDataList(list);
                List<Dictionary> data = dictionaryDataList.getData();
                assetModels.stream().
                        forEach(assetModel1 ->{
                        data.stream().forEach(dictionary -> {
                            if (assetModel1.getDictKey().equals(assetModel1.getDictKey())){
                                assetModel1.setDictionaryDataList(dictionary.getDictionaryDataList());
                            }
                        });


            });
            }
            return Result.success(assetModels);

        }
    }

